==> slm-0.2.2.tgz: package/lib/filters/brackets.js <==
var Slm = require('./slm');

function Brackets() {
  this._blockRe = /^(case|default)\b/;
  this._wrapCondRe = /^(for|switch|catch|while|if|else\s+if)\s+(?!\()((\S|\s\S)*)\s*$/;
  this._ifRe = /^(if|switch|while|for|else|finally|catch)\b/;
  this._callbackRe = /(function\s*\([^\)]*\)\s*)[^\{]/;
}

var BracketsProto = Brackets.prototype = new Slm();

BracketsProto.on_slm_control = function(exps) {
  var code = exps[2], content = exps[3], m;

  m = this._wrapCondRe.exec(code);
  if (m) {
    code = code.replace(m[2], '(' + m[2] + ')');
  }

  code = this._expandCallback(code, content);
  return ['slm', 'control', code, this.compile(content)];
};

BracketsProto.on_slm_output = function(exps) {
  var code = exps[3], content = exps[4];
  code = this._expandCallback(code, content);
  return ['slm', 'output', exps[2], code, this.compile(content)];
};

BracketsProto._expandCallback = function(code, content) {
  var index, m, postCode = '}';
  if (!this._blockRe.test(code) && !this._isEmptyExp(content)) {
    if (!this._ifRe.test(code)) {
      m = this._callbackRe.exec(code);
      if (m) {
        index = m.index + m[1].length;
        postCode += code.slice(index);
        code = code.slice(0, index);
      } else if ((index = code.lastIndexOf(')')) !== -1) {
        var firstIndex = code.indexOf('(');
        if (firstIndex === -1) {
          throw new Error('Missing open brace "(" in `' + code + '`');
        }
        var args = code.slice(firstIndex + 1, index);
        postCode += code.slice(index);
        if (/^\s*$/.test(args)) {
          code = code.slice(0, index) + 'function()';
        } else {
          code = code.slice(0, index) + ',function()';
        }
      }
    }
    code += '{';
    content.push(['code', postCode]);

  }
  return code;
};

module.exports = Brackets;

==> slm-0.3.2.tgz: package/lib/filters/brackets.js <==
var Slm = require('./slm');

var blockRe = /^(case|default)\b/;
var wrapCondRe = /^(for|switch|catch|while|if|else\s+if)\s+(?!\()((\S|\s\S)*)\s*$/;
var ifRe = /^(if|switch|while|for|else|finally|catch)\b/;
var callbackRe = /(function\s*\([^\)]*\)\s*)[^\{]/;

function Brackets() {}

var BracketsProto = Brackets.prototype = new Slm();

BracketsProto.on_slm_control = function(exps) {
  var code = exps[2], content = exps[3], m;

  m = wrapCondRe.exec(code);
  if (m) {
    code = code.replace(m[2], '(' + m[2] + ')');
  }

  code = this._expandCallback(code, content);
  return ['slm', 'control', code, this.compile(content)];
};

BracketsProto.on_slm_output = function(exps) {
  var code = exps[3], content = exps[4];
  code = this._expandCallback(code, content);
  return ['slm', 'output', exps[2], code, this.compile(content)];
};

BracketsProto._expandCallback = function(code, content) {
  var index, m, postCode = '}';
  if (!blockRe.test(code) && !this._isEmptyExp(content)) {
    if (!ifRe.test(code)) {
      m = callbackRe.exec(code);
      if (m) {
        index = m.index + m[1].length;
        postCode += code.slice(index);
        code = code.slice(0, index);
      } else if ((index = code.lastIndexOf(')')) !== -1) {
        var firstIndex = code.indexOf('(');
        if (firstIndex === -1) {
          throw new Error('Missing open brace "(" in `' + code + '`');
        }
        var args = code.slice(firstIndex + 1, index);
        postCode += code.slice(index);
        if (/^\s*$/.test(args)) {
          code = code.slice(0, index) + 'function()';
        } else {
          code = code.slice(0, index) + ',function()';
        }
      }
    }
    code += '{';
    content.push(['code', postCode]);

  }
  return code;
};

module.exports = Brackets;
